EXPORTS
	?jni_lookup@@YAP6AXXZPBD@Z @ 1 NONAME ; void (*)(void) jni_lookup(char const *)
	??0CommsClientEndpoint@comms@java@@QAE@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 2 NONAME ; java::comms::CommsClientEndpoint::CommsClientEndpoint(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	??0CommsClientEndpoint@comms@java@@QAE@XZ @ 3 NONAME ; java::comms::CommsClientEndpoint::CommsClientEndpoint(void)
	??0CommsEndpoint@comms@java@@QAE@XZ @ 4 NONAME ; java::comms::CommsEndpoint::CommsEndpoint(void)
	??0CommsMessage@comms@java@@QAE@ABV012@@Z @ 5 NONAME ; java::comms::CommsMessage::CommsMessage(class java::comms::CommsMessage const &)
	??0CommsMessage@comms@java@@QAE@PBUipcMessage_s@12@@Z @ 6 NONAME ; java::comms::CommsMessage::CommsMessage(struct java::comms::ipcMessage_s const *)
	??0CommsMessage@comms@java@@QAE@XZ @ 7 NONAME ; java::comms::CommsMessage::CommsMessage(void)
	??0CommsServerEndpoint@comms@java@@QAE@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 8 NONAME ; java::comms::CommsServerEndpoint::CommsServerEndpoint(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	??0CommsServerEndpoint@comms@java@@QAE@XZ @ 9 NONAME ; java::comms::CommsServerEndpoint::CommsServerEndpoint(void)
	??1CommsClientEndpoint@comms@java@@UAE@XZ @ 10 NONAME ; java::comms::CommsClientEndpoint::~CommsClientEndpoint(void)
	??1CommsEndpoint@comms@java@@UAE@XZ @ 11 NONAME ; java::comms::CommsEndpoint::~CommsEndpoint(void)
	??1CommsMessage@comms@java@@UAE@XZ @ 12 NONAME ; java::comms::CommsMessage::~CommsMessage(void)
	??1CommsServerEndpoint@comms@java@@UAE@XZ @ 13 NONAME ; java::comms::CommsServerEndpoint::~CommsServerEndpoint(void)
	??4CommsMessage@comms@java@@QAEAAV012@ABV012@@Z @ 14 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator=(class java::comms::CommsMessage const &)
	??5CommsMessage@comms@java@@QAEAAV012@AAH@Z @ 15 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator>>(int &)
	??5CommsMessage@comms@java@@QAEAAV012@AAV?$basic_string@DV?$char_traits@D@std@@V?$allocator@D@2@@std@@@Z @ 16 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator>>(class std::basic_string<char, class std::char_traits<char>, class std::allocator<char> > &)
	??5CommsMessage@comms@java@@QAEAAV012@AAV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 17 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator>>(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > &)
	??5CommsMessage@comms@java@@QAEAAV012@AAVUid@util@2@@Z @ 18 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator>>(class java::util::Uid &)
	??5CommsMessage@comms@java@@QAEAAV012@AA_J@Z @ 19 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator>>(long long &)
	??6CommsMessage@comms@java@@QAEAAV012@ABH@Z @ 20 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator<<(int const &)
	??6CommsMessage@comms@java@@QAEAAV012@ABV?$basic_string@DV?$char_traits@D@std@@V?$allocator@D@2@@std@@@Z @ 21 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator<<(class std::basic_string<char, class std::char_traits<char>, class std::allocator<char> > const &)
	??6CommsMessage@comms@java@@QAEAAV012@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 22 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator<<(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	??6CommsMessage@comms@java@@QAEAAV012@ABVUid@util@2@@Z @ 23 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator<<(class java::util::Uid const &)
	??6CommsMessage@comms@java@@QAEAAV012@AB_J@Z @ 24 NONAME ; class java::comms::CommsMessage & java::comms::CommsMessage::operator<<(long long const &)
	??7CommsMessage@comms@java@@QBE_NXZ @ 25 NONAME ; bool java::comms::CommsMessage::operator!(void) const
	??BCommsMessage@comms@java@@QBEPAXXZ @ 26 NONAME ; java::comms::CommsMessage::operator void *(void) const
	?attachToVm@CommsEndpoint@comms@java@@UAEHPAUJNIEnv_@@@Z @ 27 NONAME ; int java::comms::CommsEndpoint::attachToVm(struct JNIEnv_ *)
	?begin@CommsMessage@comms@java@@QAEXXZ @ 28 NONAME ; void java::comms::CommsMessage::begin(void)
	?connect@CommsClientEndpoint@comms@java@@UAEHH@Z @ 29 NONAME ; int java::comms::CommsClientEndpoint::connect(int)
	?detachFromVm@CommsClientEndpoint@comms@java@@UAEHXZ @ 30 NONAME ; int java::comms::CommsClientEndpoint::detachFromVm(void)
	?detachFromVm@CommsEndpoint@comms@java@@UAEHXZ @ 31 NONAME ; int java::comms::CommsEndpoint::detachFromVm(void)
	?detachFromVm@CommsServerEndpoint@comms@java@@UAEHXZ @ 32 NONAME ; int java::comms::CommsServerEndpoint::detachFromVm(void)
	?disconnect@CommsClientEndpoint@comms@java@@UAEHXZ @ 33 NONAME ; int java::comms::CommsClientEndpoint::disconnect(void)
	?find@CommsClientEndpoint@comms@java@@SAPAV123@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 34 NONAME ; class java::comms::CommsClientEndpoint * java::comms::CommsClientEndpoint::find(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?find@CommsServerEndpoint@comms@java@@SAPAV123@ABV?$basic_string@_WV?$char_traits@_W@std@@V?$allocator@_W@2@@std@@@Z @ 35 NONAME ; class java::comms::CommsServerEndpoint * java::comms::CommsServerEndpoint::find(class std::basic_string<wchar_t, class std::char_traits<wchar_t>, class std::allocator<wchar_t> > const &)
	?generateMessageReference@CommsEndpoint@comms@java@@MAEHXZ @ 36 NONAME ; int java::comms::CommsEndpoint::generateMessageReference(void)
	?getMessageId@CommsMessage@comms@java@@QBEHXZ @ 37 NONAME ; int java::comms::CommsMessage::getMessageId(void) const
	?getMessageRef@CommsMessage@comms@java@@QBEHXZ @ 38 NONAME ; int java::comms::CommsMessage::getMessageRef(void) const
	?getModuleId@CommsMessage@comms@java@@QBEHXZ @ 39 NONAME ; int java::comms::CommsMessage::getModuleId(void) const
	?getReceiver@CommsMessage@comms@java@@QBEHXZ @ 40 NONAME ; int java::comms::CommsMessage::getReceiver(void) const
	?getSender@CommsMessage@comms@java@@QBEHXZ @ 41 NONAME ; int java::comms::CommsMessage::getSender(void) const
	?handleIpcMessage@CommsEndpoint@comms@java@@MAEXAAVCommsMessage@23@@Z @ 42 NONAME ; void java::comms::CommsEndpoint::handleIpcMessage(class java::comms::CommsMessage &)
	?handleMessage@CommsEndpoint@comms@java@@MAEHAAVCommsMessage@23@@Z @ 43 NONAME ; int java::comms::CommsEndpoint::handleMessage(class java::comms::CommsMessage &)
	?hasPermission@CommsMessage@comms@java@@QBE_NABW4CommsPermission@23@@Z @ 44 NONAME ; bool java::comms::CommsMessage::hasPermission(enum java::comms::CommsPermission const &) const
	?onExit@CommsEndpoint@comms@java@@MAEXXZ @ 45 NONAME ; void java::comms::CommsEndpoint::onExit(void)
	?onStart@CommsEndpoint@comms@java@@MAEXXZ @ 46 NONAME ; void java::comms::CommsEndpoint::onStart(void)
	?processMessage@CommsEndpoint@comms@java@@MAEXPBUipcMessage_s@23@@Z @ 47 NONAME ; void java::comms::CommsEndpoint::processMessage(struct java::comms::ipcMessage_s const *)
	?registerDefaultJavaListener@CommsEndpoint@comms@java@@UAEHPAV_jobject@@PAUJNIEnv_@@@Z @ 48 NONAME ; int java::comms::CommsEndpoint::registerDefaultJavaListener(class _jobject *, struct JNIEnv_ *)
	?registerDefaultListener@CommsEndpoint@comms@java@@UAEHPAVCommsListener@23@@Z @ 49 NONAME ; int java::comms::CommsEndpoint::registerDefaultListener(class java::comms::CommsListener *)
	?registerJavaListener@CommsEndpoint@comms@java@@UAEHHPAV_jobject@@PAUJNIEnv_@@@Z @ 50 NONAME ; int java::comms::CommsEndpoint::registerJavaListener(int, class _jobject *, struct JNIEnv_ *)
	?registerListener@CommsEndpoint@comms@java@@UAEHHPAVCommsListener@23@@Z @ 51 NONAME ; int java::comms::CommsEndpoint::registerListener(int, class java::comms::CommsListener *)
	?replyTo@CommsMessage@comms@java@@QAEXABV123@@Z @ 52 NONAME ; void java::comms::CommsMessage::replyTo(class java::comms::CommsMessage const &)
	?reset@CommsMessage@comms@java@@QAEXXZ @ 53 NONAME ; void java::comms::CommsMessage::reset(void)
	?send@CommsClientEndpoint@comms@java@@UAEHAAVCommsMessage@23@@Z @ 54 NONAME ; int java::comms::CommsClientEndpoint::send(class java::comms::CommsMessage &)
	?send@CommsServerEndpoint@comms@java@@UAEHAAVCommsMessage@23@@Z @ 55 NONAME ; int java::comms::CommsServerEndpoint::send(class java::comms::CommsMessage &)
	?sendReceive@CommsEndpoint@comms@java@@UAEHAAVCommsMessage@23@0H@Z @ 56 NONAME ; int java::comms::CommsEndpoint::sendReceive(class java::comms::CommsMessage &, class java::comms::CommsMessage &, int)
	?setMessageId@CommsMessage@comms@java@@QAEXH@Z @ 57 NONAME ; void java::comms::CommsMessage::setMessageId(int)
	?setMessageRef@CommsMessage@comms@java@@QAEXH@Z @ 58 NONAME ; void java::comms::CommsMessage::setMessageRef(int)
	?setModuleId@CommsMessage@comms@java@@QAEXH@Z @ 59 NONAME ; void java::comms::CommsMessage::setModuleId(int)
	?setReceiver@CommsMessage@comms@java@@QAEXH@Z @ 60 NONAME ; void java::comms::CommsMessage::setReceiver(int)
	?setSender@CommsMessage@comms@java@@QAEXH@Z @ 61 NONAME ; void java::comms::CommsMessage::setSender(int)
	?start@CommsServerEndpoint@comms@java@@UAEHH@Z @ 62 NONAME ; int java::comms::CommsServerEndpoint::start(int)
	?stop@CommsServerEndpoint@comms@java@@UAEHXZ @ 63 NONAME ; int java::comms::CommsServerEndpoint::stop(void)
	?toByteArray@CommsMessage@comms@java@@QAEPADXZ @ 64 NONAME ; char * java::comms::CommsMessage::toByteArray(void)
	?toString@CommsMessage@comms@java@@QBE?AV?$basic_string@DV?$char_traits@D@std@@V?$allocator@D@2@@std@@XZ @ 65 NONAME ; class std::basic_string<char, class std::char_traits<char>, class std::allocator<char> > java::comms::CommsMessage::toString(void) const
	?unregisterDefaultJavaListener@CommsEndpoint@comms@java@@UAEHPAV_jobject@@PAUJNIEnv_@@@Z @ 66 NONAME ; int java::comms::CommsEndpoint::unregisterDefaultJavaListener(class _jobject *, struct JNIEnv_ *)
	?unregisterDefaultListener@CommsEndpoint@comms@java@@UAEHPAVCommsListener@23@@Z @ 67 NONAME ; int java::comms::CommsEndpoint::unregisterDefaultListener(class java::comms::CommsListener *)
	?unregisterJavaListener@CommsEndpoint@comms@java@@UAEHHPAV_jobject@@PAUJNIEnv_@@@Z @ 68 NONAME ; int java::comms::CommsEndpoint::unregisterJavaListener(int, class _jobject *, struct JNIEnv_ *)
	?unregisterListener@CommsEndpoint@comms@java@@UAEHHPAVCommsListener@23@@Z @ 69 NONAME ; int java::comms::CommsEndpoint::unregisterListener(int, class java::comms::CommsListener *)

